|
Neko 1.99.9
A portable framework for high-order spectral element flow simulations
|


Go to the source code of this file.
Functions | |
| template<typename T , const int LX, const int CHUNKS> | |
| __global__ void | ax_helm_compr_kernel_1d (T *__restrict__ w, const T *__restrict__ u, const T *__restrict__ dx, const T *__restrict__ dy, const T *__restrict__ dz, const T *__restrict__ dxt, const T *__restrict__ dyt, const T *__restrict__ dzt, const T *__restrict__ h1, const T *__restrict__ g11, const T *__restrict__ g22, const T *__restrict__ g33, const T *__restrict__ g12, const T *__restrict__ g13, const T *__restrict__ g23, const int *__restrict__ ind) |
| template<typename T , const int LX, const int EB> | |
| __global__ void | __launch_bounds__ ((LX *LX *EB)) ax_helm_compr_kernel_kstep(T *__restrict__ w |
| if (eb==0) | |
| for (int k=0;k< LX;++k) | |
| __syncthreads () | |
| if (active) | |
| template<typename T , const int LX, const int NW> | |
| __global__ void | __launch_bounds__ ((32 *NW)) ax_helm_compr_kernel_dmma(T *__restrict__ w |
| template<typename T , const int LX, const int NW> | |
| static bool | ax_helm_compr_dmma_tma_batch_optin () |

| __global__ void __launch_bounds__ | ( | (LX *LX *EB) | ) |
Device kernel for axhelm with padding in shared memory to remove bank conflicts when LX is a power of 2
| __syncthreads | ( | ) |

| __global__ void ax_helm_compr_kernel_1d | ( | T *__restrict__ | w, |
| const T *__restrict__ | u, | ||
| const T *__restrict__ | dx, | ||
| const T *__restrict__ | dy, | ||
| const T *__restrict__ | dz, | ||
| const T *__restrict__ | dxt, | ||
| const T *__restrict__ | dyt, | ||
| const T *__restrict__ | dzt, | ||
| const T *__restrict__ | h1, | ||
| const T *__restrict__ | g11, | ||
| const T *__restrict__ | g22, | ||
| const T *__restrict__ | g33, | ||
| const T *__restrict__ | g12, | ||
| const T *__restrict__ | g13, | ||
| const T *__restrict__ | g23, | ||
| const int *__restrict__ | ind | ||
| ) |
Device kernel for axhelm
Definition at line 88 of file ax_helm_compr_kernel.h.

| for | ( | ) |
| if | ( | active | ) |
| if | ( | eb | = = 0 | ) |
Definition at line 252 of file ax_helm_compr_kernel.h.
Definition at line 243 of file ax_helm_compr_kernel.h.
| __global__ void T *__restrict__ av |
Definition at line 974 of file ax_helm_compr_kernel.h.
| __global__ void T *__restrict__ T *__restrict__ aw |
Definition at line 975 of file ax_helm_compr_kernel.h.
Definition at line 200 of file ax_helm_compr_kernel.h.
| __global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dy |
Definition at line 201 of file ax_helm_compr_kernel.h.
| __global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dz |
Definition at line 202 of file ax_helm_compr_kernel.h.
| const int e_blk = blockIdx.x * EB + eb |
Definition at line 242 of file ax_helm_compr_kernel.h.
Definition at line 241 of file ax_helm_compr_kernel.h.
Definition at line 204 of file ax_helm_compr_kernel.h.
Definition at line 207 of file ax_helm_compr_kernel.h.
Definition at line 208 of file ax_helm_compr_kernel.h.
Definition at line 205 of file ax_helm_compr_kernel.h.
Definition at line 209 of file ax_helm_compr_kernel.h.
Definition at line 206 of file ax_helm_compr_kernel.h.
Definition at line 203 of file ax_helm_compr_kernel.h.
| const int i = threadIdx.x |
Definition at line 246 of file ax_helm_compr_kernel.h.
Definition at line 210 of file ax_helm_compr_kernel.h.
Definition at line 245 of file ax_helm_compr_kernel.h.
Definition at line 211 of file ax_helm_compr_kernel.h.
| T ru |
Definition at line 232 of file ax_helm_compr_kernel.h.
| T rut |
Definition at line 234 of file ax_helm_compr_kernel.h.
| T ruw |
Definition at line 1029 of file ax_helm_compr_kernel.h.
| T rv |
Definition at line 1026 of file ax_helm_compr_kernel.h.
| T rvt |
Definition at line 1034 of file ax_helm_compr_kernel.h.
| T rvw |
Definition at line 1030 of file ax_helm_compr_kernel.h.
| T rw |
Definition at line 233 of file ax_helm_compr_kernel.h.
| T rwt |
Definition at line 1035 of file ax_helm_compr_kernel.h.
| T rww |
Definition at line 1031 of file ax_helm_compr_kernel.h.
| __shared__ T shdy |
Definition at line 215 of file ax_helm_compr_kernel.h.
| __shared__ T shdz |
Definition at line 216 of file ax_helm_compr_kernel.h.
| __shared__ T shu |
Definition at line 219 of file ax_helm_compr_kernel.h.
| __shared__ T shur |
Definition at line 220 of file ax_helm_compr_kernel.h.
| __shared__ T shus |
Definition at line 221 of file ax_helm_compr_kernel.h.
| __shared__ T shv |
Definition at line 1002 of file ax_helm_compr_kernel.h.
| __shared__ T shvr |
Definition at line 1003 of file ax_helm_compr_kernel.h.
| __shared__ T shvs |
Definition at line 1004 of file ax_helm_compr_kernel.h.
| __shared__ T shw |
Definition at line 1006 of file ax_helm_compr_kernel.h.
| __shared__ T shwr |
Definition at line 1007 of file ax_helm_compr_kernel.h.
| __shared__ T shws |
Definition at line 1008 of file ax_helm_compr_kernel.h.
Definition at line 199 of file ax_helm_compr_kernel.h.
Definition at line 977 of file ax_helm_compr_kernel.h.
| __global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ w |
Definition at line 978 of file ax_helm_compr_kernel.h.